summaryrefslogtreecommitdiff
path: root/vm
diff options
context:
space:
mode:
authorKeith Seitz <keiths@redhat.com>2007-02-22 23:37:53 +0000
committerKeith Seitz <keiths@redhat.com>2007-02-22 23:37:53 +0000
commit7fb11e908097c10d9dd9deed3deea3aa5a7fa200 (patch)
tree4556acdaab2557b2b69395885ba594eec8f8d4ae /vm
parent368e10f797ad2d14956509a3edce6383f49ff249 (diff)
downloadclasspath-7fb11e908097c10d9dd9deed3deea3aa5a7fa200.tar.gz
* vm/refernece/gnu/classpath/jdwp/VMVirtualMachine.java
(getAllLoadedClassesCount): Remove. (getAllLoadedClasses): Return a Collection. * gnu/classpath/jdwp/processor/VirtualMachineCommandSet.java (executeClassesBySignature): VMVirtualMachine.getAllLoadedClasses now returns Collection. (executeAllClasses): Likewise. Get size of return from Colleciton instead of calling getAllLoadedClassesCount.
Diffstat (limited to 'vm')
-rw-r--r--vm/reference/gnu/classpath/jdwp/VMVirtualMachine.java14
1 files changed, 4 insertions, 10 deletions
diff --git a/vm/reference/gnu/classpath/jdwp/VMVirtualMachine.java b/vm/reference/gnu/classpath/jdwp/VMVirtualMachine.java
index efa106c16..dbd8449d7 100644
--- a/vm/reference/gnu/classpath/jdwp/VMVirtualMachine.java
+++ b/vm/reference/gnu/classpath/jdwp/VMVirtualMachine.java
@@ -1,7 +1,7 @@
/* VMVirtualMachine.java -- A reference implementation of a JDWP virtual
machine
- Copyright (C) 2005, 2006 Free Software Foundation
+ Copyright (C) 2005, 2006, 2007 Free Software Foundation
This file is part of GNU Classpath.
@@ -48,7 +48,7 @@ import gnu.classpath.jdwp.util.MethodResult;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import java.util.ArrayList;
-import java.util.Iterator;
+import java.util.Collection;
/**
* A virtual machine according to JDWP.
@@ -170,15 +170,9 @@ public class VMVirtualMachine
throws JdwpException;
/**
* Returns a count of the number of loaded classes in the VM
*/
- public static native int getAllLoadedClassesCount()
- throws JdwpException;
-
- /**
- * Returns an iterator over all the loaded classes in the VM
- */
- public static native Iterator getAllLoadedClasses()
+ public static native Collection getAllLoadedClasses()
throws JdwpException;
/**
@@ -170,15 +170,9 @@ public class VMVirtualMachine
throws JdwpException;
/**
- * Returns a count of the number of loaded classes in the VM
+ * Returns a Collection of all classes loaded in the VM
*/